summaryrefslogtreecommitdiffstats
path: root/khtml/css/cssstyleselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/css/cssstyleselector.h')
-rw-r--r--khtml/css/cssstyleselector.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/css/cssstyleselector.h b/khtml/css/cssstyleselector.h
index 23d854bc0..5b9946342 100644
--- a/khtml/css/cssstyleselector.h
+++ b/khtml/css/cssstyleselector.h
@@ -76,7 +76,7 @@ namespace khtml
/**
* this class selects a RenderStyle for a given Element based on the
* collection of stylesheets it contains. This is just a virtual base class
* for specific implementations of the Selector. At the moment only CSSStyleSelector
* exists, but someone may wish to implement XSL...
*/
@@ -136,7 +136,7 @@ namespace khtml
bool strictParsing;
struct Encodedurl {
- TQString host; //also contains protocol
+ TQString host; //also tqcontains protocol
TQString path;
TQString file;
} encodedurl;
@@ -290,7 +290,7 @@ public:
unsigned int selector;
unsigned int position;
- Q_UINT32 priority;
+ TQ_UINT32 priority;
};
/*
@@ -76,7 +76,7 @@ namespace khtml
/**
* this class selects a RenderStyle for a given Element based on the
- * collection of stylesheets it contains. This is just a virtual base class
+ * collection of stylesheets it tqcontains. This is just a virtual base class
* for specific implementations of the Selector. At the moment only CSSStyleSelector
* exists, but someone may wish to implement XSL...